/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "seaShader.h"

SeaShader::SeaShader(int nbLightsDir, int nbLightsSpot, int nbLightsPoint):
	Shader(), mNbLightsDir(nbLightsDir), mNbLightsSpot(nbLightsSpot), mNbLightsPoint(nbLightsPoint) {
	
	ShaderWriter writer;
		
	//vertex shader sources
	std::vector<std::string> vsFilenames;
	std::vector<std::string> vsGeneratedSources;
	std::string vsMainSourceFile;
		
	writer.setNbLights(nbLightsDir, nbLightsSpot, nbLightsPoint);
	writer.setNbMaps(0, 1, 0, 0);		

	vsGeneratedSources.push_back(writer.writeLightingVertexShaderSourceCode()); 
	vsMainSourceFile = "perFragLight_main.vert";
		
		
	//fragment shader sources
	std::vector<std::string> fsFilenames;
	std::vector<std::string> fsGeneratedSources;
	std::string fsMainSourceFile;
	
	fsFilenames.push_back("perFragLight_lightingFunctions.frag");
	
	fsGeneratedSources.push_back(writer.writeLightingFragmentShaderSourceCode()); 
	fsMainSourceFile = "skyInTheSea_main.frag";
			
													 
	id = loadProgram(vsFilenames, vsGeneratedSources, vsMainSourceFile, fsFilenames, fsGeneratedSources, fsMainSourceFile);
							
	if(id == 0) {
		std::cerr << "The per fragment lighting shader cannot be loaded." << std::endl;
	} 			
}

